@@ -1,4 +1,4 @@
-/* $Id: ppp.h,v 1.16 2003/10/20 20:11:58 hadess Exp $ */
+/* $Id: ppp.h,v 1.18 2004/12/06 14:44:10 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -30,7 +30,7 @@
 G_BEGIN_DECLS
 
 #define GLIBTOP_PPP_STATE	0
-#define GLIBTOP_PPP_BYTES_IN	1	
+#define GLIBTOP_PPP_BYTES_IN	1
 #define GLIBTOP_PPP_BYTES_OUT	2
 
 #define GLIBTOP_MAX_PPP		3
@@ -69,16 +69,6 @@ void glibtop_init_ppp_s (glibtop *server);
 void glibtop_get_ppp_s (glibtop *server, glibtop_ppp *buf, unsigned short device);
 #endif
 
-#ifdef GLIBTOP_NAMES
-
-/* You need to link with -lgtop_names to get this stuff here. */
-
-extern const char *glibtop_names_ppp [];
-extern const unsigned glibtop_types_ppp [];
-extern const char *glibtop_labels_ppp [];
-extern const char *glibtop_descriptions_ppp [];
-
-#endif
 
 G_END_DECLS
 
