@@ -1,4 +1,4 @@
-/* $Id: procmap.h,v 1.19 2004/03/05 19:50:41 hadess Exp $ */
+/* $Id: procmap.h,v 1.20 2004/12/06 14:44:10 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -94,16 +94,6 @@ glibtop_map_entry *
 glibtop_get_proc_map_s (glibtop *server, glibtop_proc_map *buf, pid_t pid);
 #endif
 
-#ifdef GLIBTOP_NAMES
-
-/* You need to link with -lgtop_names to get this stuff here. */
-
-extern const char *glibtop_names_proc_map [];
-extern const unsigned glibtop_types_proc_map [];
-extern const char *glibtop_labels_proc_map [];
-extern const char *glibtop_descriptions_proc_map [];
-
-#endif
 
 G_END_DECLS
 
