@@ -1,4 +1,4 @@
-/* $Id: read.c,v 1.15 2003/10/20 15:19:41 hadess Exp $ */
+/* $Id: read.c,v 1.21 2005/02/15 12:48:33 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -23,7 +23,8 @@
 
 #include <config.h>
 #include <glibtop/read.h>
-#include <libgnome/gnome-i18n.h>
+#include <glibtop/error.h>
+#include "libgtop-i18n.h"
 
 
 /* Reads some data from server. */
@@ -31,37 +32,24 @@
 static void
 do_read (int s, void *ptr, size_t total_size)
 {
-	int nread;
-	size_t already_read = 0, remaining = total_size;
-	char *tmp_ptr;
-	
-	while (already_read < total_size) {
-		nread = recv (s, ptr, remaining, 0);
+	ssize_t nread;
 
-		if (nread == 0) {
-			close (s);
-			continue;
-		}
-		
-		if (nread <= 0) {
-			glibtop_error_io ("recv");
-			return;
-		}
-		
-		already_read += nread;
-		remaining -= nread;
-		/* (char *) ptr += nread; */
-		tmp_ptr = ptr;
-		tmp_ptr += nread;
-		ptr = tmp_ptr;
+	if(!total_size) return;
+
+	while (total_size && (nread = recv (s, ptr, total_size, 0)) > 0) {
+		total_size -= nread;
+		ptr = (char*)ptr + nread;
 	}
+
+	if(nread == 0)
+		close (s);
+	else if (nread < 0)
+		glibtop_error_io ("recv");
 }
 
 void
 glibtop_read_l (glibtop *server, size_t size, void *buf)
 {
-	int ret = 0;
-
 	glibtop_init_r (&server, 0, 0);
 
 #ifdef DEBUG
@@ -71,9 +59,11 @@ glibtop_read_l (glibtop *server, size_t size, void *buf)
 	if (server->socket) {
 		do_read (server->socket, buf, size);
 	} else {
-		ret = read (server->input [0], buf, size);
+		if(read (server->input [0], buf, size) < 0)
+			glibtop_error_io_r (
+				server,
+				ngettext ("read %d byte",
+					  "read %d bytes", size),
+				size);
 	}
-
-	if (ret < 0)
-		glibtop_error_io_r (server, _("read %d bytes"), size);
 }
