@@ -1,4 +1,4 @@
-/* $Id: proclist.c,v 1.15 2003/10/19 16:55:49 carlos Exp $ */
+/* $Id: proclist.c,v 1.16 2004/07/18 20:33:56 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -45,7 +45,7 @@ glibtop_init_proclist_s (glibtop *server)
 
 unsigned *
 glibtop_get_proclist_s (glibtop *server, glibtop_proclist *buf,
-			int64_t which, int64_t arg)
+			gint64 which, gint64 arg)
 {
 	memset (buf, 0, sizeof (glibtop_proclist));
 	return NULL;
