@@ -1,4 +1,4 @@
-/* $Id: uptime.c,v 1.14 2003/10/19 16:55:56 carlos Exp $ */
+/* $Id: uptime.c,v 1.16 2004/05/25 14:44:45 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -27,6 +27,8 @@
 
 #include <glibtop_suid.h>
 
+#include <time.h>
+
 static const unsigned long _glibtop_sysdeps_uptime =
 (1 << GLIBTOP_UPTIME_UPTIME) + (1 << GLIBTOP_UPTIME_IDLETIME);
 
@@ -56,6 +58,7 @@ glibtop_get_uptime_p (glibtop *server, glibtop_uptime *buf)
 
 	buf->uptime = (double) cpu.total / (double) cpu.frequency;
 	buf->idletime = (double) cpu.idle / (double) cpu.frequency;
+	buf->boot_time = (guint64) time(NULL) - (guint64) buf->uptime;
 
 	buf->flags = _glibtop_sysdeps_uptime;
 }
